==> elgg-1.9.2.zip: elgg-1.9.2/mod/bookmarks/languages/es.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'bookmarks' => "Marcadores",
	'bookmarks:add' => "Agregar un marcador",
	'bookmarks:edit' => "Editar marcador",
	'bookmarks:owner' => "Marcadores de %s",
	'bookmarks:friends' => "Marcadores de amigos",
	'bookmarks:everyone' => "Todos los marcadores",
	'bookmarks:this' => "Marcar esta p&aacute;gina",
	'bookmarks:this:group' => "Marcar en %s",
	'bookmarks:bookmarklet' => "Obtener marcadores",
	'bookmarks:bookmarklet:group' => "Obtener widget de marcadores del grupo",
	'bookmarks:inbox' => "Bandeja de entrada de marcadores",
	'bookmarks:with' => "Compartir con",
	'bookmarks:new' => "Un nuevo marcador",
	'bookmarks:address' => "Direcciones del marcador",
	'bookmarks:none' => 'No hay marcadores',

	'bookmarks:notify:summary' => 'Nuevo marcador llamado %s',
	'bookmarks:notify:subject' => 'Nuevo marcador: %s',
	'bookmarks:notify:body' =>
'%s agrego un nuevo marcador: %s

Dirección: %s

%s

Ver y comentar en el marcador:
%s
',

	'bookmarks:delete:confirm' => "&ntilde;Seguro que deseas borrar este marcador?",

	'bookmarks:numbertodisplay' => 'N&uacute;mero de marcadores a mostrar',

	'bookmarks:shared' => "Marcado",
	'bookmarks:visit' => "Visitar fuente",
	'bookmarks:recent' => "Marcadores recientes",

	'river:create:object:bookmarks' => '%s ha marcado %s',
	'river:comment:object:bookmarks' => '%s ha comentado en el marcador %s',
	'bookmarks:river:annotate' => 'ha comentado este marcador',
	'bookmarks:river:item' => 'un item',

	'item:object:bookmarks' => 'Marcadores',

	'bookmarks:group' => 'Marcadores de grupos',
	'bookmarks:enablebookmarks' => 'Habilitar marcadores para Grupos',
	'bookmarks:nogroup' => 'Este Grupo no tiene marcadores a&uacute;n',
	
	/**
	 * Widget and bookmarklet
	 */
	'bookmarks:widget:description' => "Mostrar los &uacute;ltimo0s marcadores.",

	'bookmarks:bookmarklet:description' =>
			"El widget de marcadores permite compartir cualquier recurso de la Web con tus amigos, o sinmplemente para ti mismo. Para usarlo, simplemente arrastra el enlace a la barra de marcadores de tu navegador:",

	'bookmarks:bookmarklet:descriptionie' =>
			"Si usas Internet Explorer, necesitas hacer click con el bot&oacute;n derecho del rat&oacute;n al enlace, select 'add to favorites', y entonces a la barra de marcadores.",

	'bookmarks:bookmarklet:description:conclusion' =>
			"A continuación, puedes guardar cualquier página que visite haciendo clic en él en cualquier momento.",

	/**
	 * Status messages
	 */

	'bookmarks:save:success' => "El item fue marcado exitosamente.",
	'bookmarks:delete:success' => "El marcador ha sido borrado.",

	/**
	 * Error messages
	 */

	'bookmarks:save:failed' => "El marcador no pudo ser guardado. Aseg&uacute;rate de que el t&iacute;tulo y el enlace est&eacute;n correctamente escritos.",
	'bookmarks:save:invalid' => "La direcci&oacute;n es inv&aacute;lida y no pudo ser guardada.",
	'bookmarks:delete:failed' => "El marcador no pudo ser borrado. Intenta de nuevo.",
	'bookmarks:unknown_bookmark' => 'No se puede encontrar el marcador requerido',
);

==> elgg-1.10.1.zip: elgg-1.10.1/mod/bookmarks/languages/es.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'bookmarks' => "Marcadores",
	'bookmarks:add' => "Agregar un marcador",
	'bookmarks:edit' => "Editar marcador",
	'bookmarks:owner' => "Marcadores de %s",
	'bookmarks:friends' => "Marcadores de amigos",
	'bookmarks:everyone' => "Todos los marcadores",
	'bookmarks:this' => "Marcar esta p&aacute;gina",
	'bookmarks:this:group' => "Marcar en %s",
	'bookmarks:bookmarklet' => "Obtener marcadores",
	'bookmarks:bookmarklet:group' => "Obtener widget de marcadores del grupo",
	'bookmarks:inbox' => "Bandeja de entrada de marcadores",
	'bookmarks:with' => "Compartir con",
	'bookmarks:new' => "Un nuevo marcador",
	'bookmarks:address' => "Direcciones del marcador",
	'bookmarks:none' => 'No hay marcadores',

	'bookmarks:notify:summary' => 'Nuevo marcador llamado %s',
	'bookmarks:notify:subject' => 'Nuevo marcador: %s',
	'bookmarks:notify:body' =>
'%s agrego un nuevo marcador: %s

Dirección: %s

%s

Ver y comentar en el marcador:
%s
',

	'bookmarks:delete:confirm' => "&ntilde;Seguro que deseas borrar este marcador?",

	'bookmarks:numbertodisplay' => 'N&uacute;mero de marcadores a mostrar',

	'bookmarks:shared' => "Marcado",
	'bookmarks:visit' => "Visitar fuente",
	'bookmarks:recent' => "Marcadores recientes",

	'river:create:object:bookmarks' => '%s ha marcado %s',
	'river:comment:object:bookmarks' => '%s ha comentado en el marcador %s',
	'bookmarks:river:annotate' => 'ha comentado este marcador',
	'bookmarks:river:item' => 'un art&iacute;culo',

	'item:object:bookmarks' => 'Marcadores',

	'bookmarks:group' => 'Marcadores de grupos',
	'bookmarks:enablebookmarks' => 'Habilitar marcadores para Grupos',
	'bookmarks:nogroup' => 'Este Grupo no tiene marcadores a&uacute;n',
	
	/**
	 * Widget and bookmarklet
	 */
	'bookmarks:widget:description' => "Mostrar los &uacute;ltimo0s marcadores.",

	'bookmarks:bookmarklet:description' =>
			"El widget de marcadores permite compartir cualquier recurso de la Web con tus amigos, o sinmplemente para ti mismo. Para usarlo, simplemente arrastra el enlace a la barra de marcadores de tu navegador:",

	'bookmarks:bookmarklet:descriptionie' =>
			"Si usas Internet Explorer, necesitas hacer click con el bot&oacute;n derecho del rat&oacute;n al enlace, select 'add to favorites', y entonces a la barra de marcadores.",

	'bookmarks:bookmarklet:description:conclusion' =>
			"A continuación, puedes guardar cualquier página que visite haciendo clic en él en cualquier momento.",

	/**
	 * Status messages
	 */

	'bookmarks:save:success' => "El item fue marcado exitosamente.",
	'bookmarks:delete:success' => "El marcador ha sido borrado.",

	/**
	 * Error messages
	 */

	'bookmarks:save:failed' => "El marcador no pudo ser guardado. Aseg&uacute;rate de que el t&iacute;tulo y el enlace est&eacute;n correctamente escritos.",
	'bookmarks:save:invalid' => "La direcci&oacute;n es inv&aacute;lida y no pudo ser guardada.",
	'bookmarks:delete:failed' => "El marcador no pudo ser borrado. Intenta de nuevo.",
	'bookmarks:unknown_bookmark' => 'No se puede encontrar el marcador requerido',
);
